@@ -17,31 +17,29 @@ from selenium.webdriver.remote.webelement import WebElement
 from selenium.webdriver.support.wait import WebDriverWait
 
 from .base import BasePage
-from .common import str_to_loc, get_available_file_name, translate_loc, format_html
-from .driver_element import DriverElement, execute_driver_find, _wait_ele
+from .common import get_usable_path
+from .driver_element import DriverElement, make_driver_ele, _wait_ele
+from .session_element import make_session_ele
 
 
 class DriverPage(BasePage):
     """DriverPage封装了页面操作的常用功能，使用selenium来获取、解析、操作网页"""
 
-    def __init__(self, driver: WebDriver, timeout: float = 10):
+    def __init__(self, driver: WebDriver, timeout: float = 10) -> None:
         """初始化函数，接收一个WebDriver对象，用来操作网页"""
         super().__init__(timeout)
         self._driver = driver
         self._wait_object = None
 
-    def __call__(self,
-                 loc_or_str: Union[Tuple[str, str], str, DriverElement, WebElement],
-                 mode: str = 'single',
-                 timeout: float = None) -> Union[DriverElement, List[DriverElement]]:
+    def __call__(self, loc_or_str: Union[Tuple[str, str], str, DriverElement, WebElement],
+                 timeout: float = None) -> Union[DriverElement, List[DriverElement], str]:
         """在内部查找元素                                           \n
-        例：ele = page('@id=ele_id')                               \n
+        例：ele = page('@id=ele_id')                              \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
-        :param mode: 'single' 或 'all'，对应查找一个或全部
         :param timeout: 超时时间
-        :return: DriverElement对象
+        :return: DriverElement对象或属性、文本
         """
-        return super().__call__(loc_or_str, mode, timeout)
+        return self.ele(loc_or_str, timeout)
 
     # -----------------共有属性和方法-------------------
     @property
@@ -54,8 +52,8 @@ class DriverPage(BasePage):
 
     @property
     def html(self) -> str:
-        """返回页面html文本"""
-        return format_html(self.driver.find_element('xpath', "//*").get_attribute("outerHTML"))
+        """返回页面的html文本"""
+        return self.driver.find_element('xpath', "//*").get_attribute("outerHTML")
 
     @property
     def json(self) -> dict:
@@ -96,22 +94,51 @@ class DriverPage(BasePage):
 
     def ele(self,
             loc_or_ele: Union[Tuple[str, str], str, DriverElement, WebElement],
-            mode: str = None,
             timeout: float = None) -> Union[DriverElement, List[DriverElement], str, None]:
-        """返回页面中符合条件的元素，默认返回第一个                                                         \n
+        """返回页面中符合条件的第一个元素                                                           \n
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
-        :param mode: 'single' 或 'all‘，对应查找一个或全部
         :param timeout: 查找元素超时时间
+        :return: DriverElement对象或属性、文本
+        """
+        return self._ele(loc_or_ele, timeout)
+
+    def eles(self,
+             loc_or_str: Union[Tuple[str, str], str],
+             timeout: float = None) -> List[DriverElement]:
+        """返回页面中所有符合条件的元素                                                                     \n
+        :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
+        :param timeout: 查找元素超时时间
+        :return: DriverElement对象或属性、文本组成的列表
+        """
+        return self._ele(loc_or_str, timeout, single=False)
+
+    def s_ele(self, loc_or_ele):
+        """查找第一个符合条件的元素以SessionElement形式返回，处理复杂页面时效率很高       \n
+        :param loc_or_ele: 元素的定位信息，可以是loc元组，或查询字符串
+        :return: SessionElement对象或属性、文本
+        """
+        return make_session_ele(self, loc_or_ele)
+
+    def s_eles(self, loc_or_str: Union[Tuple[str, str], str]):
+        """查找所有符合条件的元素以SessionElement列表形式返回                       \n
+        :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
+        :return: SessionElement对象组成的列表
+        """
+        return make_session_ele(self, loc_or_str, single=False)
+
+    def _ele(self,
+             loc_or_ele: Union[Tuple[str, str], str, DriverElement, WebElement],
+             timeout: float = None,
+             single: bool = True) -> Union[DriverElement, List[DriverElement], str, None]:
+        """返回页面中符合条件的元素，默认返回第一个                                   \n
+        :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
+        :param timeout: 查找元素超时时间
+        :param single: True则返回第一个，False则返回全部
         :return: DriverElement对象
         """
         # 接收到字符串或元组，获取定位loc元组
         if isinstance(loc_or_ele, (str, tuple)):
-            if isinstance(loc_or_ele, str):
-                loc_or_ele = str_to_loc(loc_or_ele)
-            else:
-                if len(loc_or_ele) != 2:
-                    raise ValueError("Len of loc_or_ele must be 2 when it's a tuple.")
-                loc_or_ele = translate_loc(loc_or_ele)
+            return make_driver_ele(self, loc_or_ele, single, timeout)
 
         # 接收到DriverElement对象直接返回
         elif isinstance(loc_or_ele, DriverElement):
@@ -123,22 +150,7 @@ class DriverPage(BasePage):
 
         # 接收到的类型不正确，抛出异常
         else:
-            raise ValueError('Argument loc_or_str can only be tuple, str, DriverElement, DriverElement.')
-
-        return execute_driver_find(self, loc_or_ele, mode, timeout)
-
-    def eles(self,
-             loc_or_str: Union[Tuple[str, str], str],
-             timeout: float = None) -> List[DriverElement]:
-        """返回页面中所有符合条件的元素                                                                     \n
-        :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
-        :param timeout: 查找元素超时时间
-        :return: DriverElement对象组成的列表
-        """
-        if not isinstance(loc_or_str, (tuple, str)):
-            raise TypeError('Type of loc_or_str can only be tuple or str.')
-
-        return super().eles(loc_or_str, timeout)
+            raise ValueError('loc_or_str参数只能是tuple、str、DriverElement 或 DriverElement类型。')
 
     def get_cookies(self, as_dict: bool = False) -> Union[list, dict]:
         """返回当前网站cookies"""
@@ -191,7 +203,7 @@ class DriverPage(BasePage):
                 print(f'重试 {to_url}')
 
         if is_ok is False and show_errmsg:
-            raise err if err is not None else ConnectionError('Connect error.')
+            raise err if err is not None else ConnectionError('连接异常。')
 
         return is_ok
 
@@ -294,7 +306,7 @@ class DriverPage(BasePage):
         elif isinstance(tab, (list, tuple)):
             page_handle = tab
         else:
-            raise TypeError('Argument num_or_handle can only be int, str, list or tuple.')
+            raise TypeError('num_or_handle参数只能是int、str、list 或 tuple类型。')
 
         for i in tabs:  # 遍历所有标签页，关闭非保留的
             if i not in page_handle:
@@ -370,10 +382,11 @@ class DriverPage(BasePage):
         :return: 图片完整路径
         """
         name = filename or self.title
+        if not name.lower().endswith('.png'):
+            name = f'{name}.png'
         path = Path(path).absolute()
         path.mkdir(parents=True, exist_ok=True)
-        name = get_available_file_name(str(path), f'{name}.png')
-        img_path = f'{path}{sep}{name}'
+        img_path = str(get_usable_path(f'{path}{sep}{name}'))
         self.driver.save_screenshot(img_path)
         return img_path
 
@@ -421,8 +434,8 @@ class DriverPage(BasePage):
             self.driver.execute_script(f"window.scrollBy({pixel},0);")
 
         else:
-            raise ValueError("Argument mode can only be "
-                             "'top', 'bottom', 'half', 'rightmost', 'leftmost', 'up', 'down', 'left', 'right'.")
+            raise ValueError("mode参数只能是'top', 'bottom', 'half', 'rightmost', "
+                             "'leftmost', 'up', 'down', 'left', 'right'。")
 
     def refresh(self) -> None:
         """刷新当前页面"""
@@ -446,7 +459,7 @@ class DriverPage(BasePage):
 
         else:
             if x < 0 or y < 0:
-                raise ValueError('Arguments x and y must greater than 0.')
+                raise ValueError('x 和 y参数必须大于0。')
 
             new_x = x or self.driver.get_window_size()['width']
             new_y = y or self.driver.get_window_size()['height']
