@@ -203,7 +203,7 @@ def get_match_driver(ini_path: Union[str, None] = 'default',
     :param check_version: 是否检查版本匹配
     :return: None
     """
-    save_path = save_path or '.'
+    save_path = save_path or str(Path(__file__).parent)
 
     chrome_path = chrome_path or _get_chrome_path(ini_path, show_msg)
     chrome_path = Path(chrome_path).absolute() if chrome_path else None
@@ -261,7 +261,8 @@ def _get_chrome_path(ini_path: str = None,
         path = None
 
     if path and Path(path).is_file():
-        print('ini文件中', end='')
+        if show_msg:
+            print('ini文件中', end='')
         return str(path)
 
     # -----------从注册表中获取--------------
@@ -359,7 +360,7 @@ def _download_driver(version: str, save_path: str = None, show_msg: bool = True)
 
     if remote_ver:
         url = f'https://cdn.npm.taobao.org/dist/chromedriver/{remote_ver}chromedriver_win32.zip'
-        save_path = save_path or '.'
+        save_path = save_path or Path(__file__).parent
         result = page.download(url, save_path, file_exists='overwrite', show_msg=show_msg)
 
         if result[0]:
